@@ -11,7 +11,8 @@ matrix = [
     ("python310", True),
     ("python3.6m", True),
     ("python3.6.8m", False),
-    ("anaconda-3.3.0", True),
+    ("anaconda3.3", True),
+    ("python-3.8.10", False),
     ("unknown-2.0.0", False),
     ("python3.8.unknown", False),
     ("python38.bat", WINDOWS),
